##  Applying Labels
Labels are a new feature that allows you to improve representation and understanding. In the editor, you have the flexibility to add and modify fact sheet labels in both Free Draw and Data Flow diagram types. Additionally, in Data Flow diagrams, you can also adjust labels for Interface connections.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275782877a44101495f1804f8f4843cb_LowRes.png)
To change the label for a fact sheet shape, follow these steps:
  1. Click on the Labels menu, which is located in the top toolbar.
  2. A drop-down list of fact sheet types will appear. Select the fact sheet type for which you wish to adjust the label by clicking on it.
  3. Once you click on a fact sheet type, a sub-menu will be displayed, presenting available labels for that fact sheet type.
  4. Click on the desired label from the sub-menu. All corresponding fact sheets in the diagram will be updated with the chosen label.


**Note**
  * Only one label can be selected for each fact sheet type.
  * If a fact sheet shape does not possess the selected label, the full name will be displayed instead.
